@@ -45,7 +45,17 @@ class CogEnvDecoder:
 
     def reset(self):
         obs = self._env.reset()
-        return self._get_obs(obs)
+        img = self._GetImg(obs)
+        self_pos = self._GetSelfPos(obs) #Blue one Position
+        enemy_pos = self._EnemyPos(obs)#Red one position
+        goal1 = self._GetGoal1Pos(obs)#Goal 1 position, whether it has been activated
+        goal2 = self._GetGoal2Pos(obs)#Goal 2 position, whether it has been activated
+        goal3 = self._GetGoal3Pos(obs)#Goal 3 position, whether it has been activated
+        goal4 = self._GetGoal4Pos(obs)#Goal 4 position, whether it has been activated
+        goal5 = self._GetGoal5Pos(obs)#Goal 5 position, whether it has been activated
+        self_info = self._SelfInfo(obs)#Blue one remaining HP & bullet
+        final_obs = [img, self_pos, enemy_pos, self_info, goal1, goal2, goal3, goal4, goal5]
+        return final_obs
 
     def step(self, action):
         obs, reward, done, info = self._env.step(action)
